# GenomeTreeTk

<b>[This project is in active development and not currently recommended for public use.]</b>

The genome tree toolkit is a collection of methods for working with genome trees. It currently functionality for:

<i>Measures of tree stability:</i>
* bootstrap support
* jackknife taxa support
* jackknife gene support

## Install

The simplest way to install this package is through pip:
> sudo pip install genome_tree_tk

GenomeTreeTk relies on several other software packages:

TBD

## Cite

If you find this package useful, please cite this git repository (https://github.com/dparks1134/GenomeTreeTk)

## Copyright

Copyright © 2015 Donovan Parks. See LICENSE for further details.
